@@ -42,22 +42,18 @@
 #include "endpoint.h"
 #include "gnomemeeting.h"
 #include "misc.h"
-#include "tools.h"
 #include "chat_window.h"
+#include "log_window.h"
 #include "main_window.h"
 
 #include "dialog.h"
-#include "gconf_widgets_extensions.h"
+#include "gm_conf.h"
 
 #include <h323pdu.h>
 
 #define new PNEW
 
 
-/* Declarations */
-extern GtkWidget *gm;
-
-
 /* The functions */
 GMH323Connection::GMH323Connection (GMH323EndPoint & ep, 
 				    unsigned callReference)
@@ -67,16 +63,15 @@ GMH323Connection::GMH323Connection (GMH323EndPoint & ep,
   int max_jitter = 1000;
 
   gnomemeeting_threads_enter ();
-  gw = GnomeMeeting::Process ()->GetMainWindow ();
 
   opened_audio_channels = 0;
   opened_video_channels = 0;
 
   min_jitter = 
-    gconf_get_int (AUDIO_CODECS_KEY "minimum_jitter_buffer");
+    gm_conf_get_int (AUDIO_CODECS_KEY "minimum_jitter_buffer");
 
   max_jitter = 
-    gconf_get_int (AUDIO_CODECS_KEY "maximum_jitter_buffer");
+    gm_conf_get_int (AUDIO_CODECS_KEY "maximum_jitter_buffer");
   gnomemeeting_threads_leave ();
 
   SetAudioJitterDelay (PMAX (min_jitter, 20), PMIN (max_jitter, 1000));
@@ -106,6 +101,9 @@ BOOL
 GMH323Connection::OnLogicalChannel (H323Channel *channel,
 				    BOOL is_closing)
 {
+  GtkWidget *history_window = NULL;
+  GtkWidget *main_window = NULL;
+  
   PString codec_name;
   BOOL is_encoding = FALSE;
   BOOL is_video = FALSE;
@@ -113,14 +111,18 @@ GMH323Connection::OnLogicalChannel (H323Channel *channel,
   
   gchar *msg = NULL;
   
+  history_window = GnomeMeeting::Process ()->GetHistoryWindow ();
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
+
+  
   PWaitAndSignal m(channels);
 
-  is_video = (channel->GetCodec ()->IsDescendant (H323VideoCodec::Class ()));
+  is_video = (PIsDescendant (channel->GetCodec (), H323VideoCodec));
   is_encoding = (channel->GetDirection () == H323Channel::IsTransmitter);
   codec_name = channel->GetCapability ().GetFormatName ();
 
   gnomemeeting_threads_enter ();
-  preview = gconf_get_bool (VIDEO_DEVICES_KEY "enable_preview");
+  preview = gm_conf_get_bool (VIDEO_DEVICES_KEY "enable_preview");
   gnomemeeting_threads_leave ();
 
   if (is_video) {
@@ -165,11 +167,11 @@ GMH323Connection::OnLogicalChannel (H323Channel *channel,
 
   /* Update the GUI and menus wrt opened channels */
   gnomemeeting_threads_enter ();
-  gnomemeeting_log_insert (msg);
-  gnomemeeting_menu_update_sensitivity (is_video, is_video?is_receiving_video:is_receiving_audio, is_video?is_transmitting_video:is_transmitting_audio);
-  gnomemeeting_main_window_update_sensitivity (is_video, is_video?is_receiving_video:is_receiving_audio, is_video?is_transmitting_video:is_transmitting_audio);
+  gm_history_window_insert (history_window, msg);
+  gm_main_window_update_sensitivity (main_window, is_video, is_video?is_receiving_video:is_receiving_audio, is_video?is_transmitting_video:is_transmitting_audio);
   if (!is_receiving_video && !is_transmitting_video && !preview)
-    gnomemeeting_init_main_window_logo (gw->main_video_image);
+    gm_main_window_update_logo (main_window);
+  gm_main_window_set_channel_pause (main_window, FALSE, is_video);
   gnomemeeting_threads_leave ();
   
   g_free (msg);
@@ -182,10 +184,10 @@ GMH323Connection::OpenLogicalChannel (const H323Capability &capability,
 				      unsigned session_id,  
 				      H323Channel::Directions dir)
 {
-  GmWindow *gw = NULL;
+  GtkWidget *history_window = NULL;
   BOOL success = FALSE;
   
-  gw = GnomeMeeting::Process ()->GetMainWindow ();
+  history_window = GnomeMeeting::Process ()->GetHistoryWindow ();
   
   success =
     H323Connection::OpenLogicalChannel (capability, session_id, dir);
@@ -196,10 +198,11 @@ GMH323Connection::OpenLogicalChannel (const H323Capability &capability,
   if (!success) {
     
     gnomemeeting_threads_enter ();
-    gnomemeeting_log_insert ((dir == H323Channel::IsTransmitter)
-				? _("Failure opening %s for transmission, will try with next common codec")
-				: _("Failure opening %s for reception, will try with next common codec"),
-				(const char *) capability.GetFormatName ());
+    gm_history_window_insert (history_window,
+			     (dir == H323Channel::IsTransmitter)
+			     ? _("Failure opening %s for transmission, will try with next common codec")
+			     : _("Failure opening %s for reception, will try with next common codec"),
+			     (const char *) capability.GetFormatName ());
     gnomemeeting_threads_leave ();
   }
   
@@ -222,10 +225,10 @@ GMH323Connection::OnAnswerCall (const PString & caller,
 
   gnomemeeting_threads_enter ();  
   icm = (IncomingCallMode)
-    gconf_get_int (CALL_OPTIONS_KEY "incoming_call_mode");
+    gm_conf_get_int (CALL_OPTIONS_KEY "incoming_call_mode");
   gnomemeeting_threads_leave ();
 
-  if (icm == FREE_FOR_CHAT) 
+  if (icm == AUTO_ANSWER)
     return AnswerCallNow; 
   
   return AnswerCallPending;
@@ -234,10 +237,16 @@ GMH323Connection::OnAnswerCall (const PString & caller,
 
 void GMH323Connection::OnUserInputString(const PString & value)
 {
+  GtkWidget *chat_window = NULL;
+  
   PString val;
   PString remote = GetRemotePartyName ();
   PINDEX bracket;
 
+  
+  chat_window = GnomeMeeting::Process ()->GetChatWindow ();
+  
+  
   /* The remote party name has to be converted to UTF-8, but not
      the text */
   gchar *utf8_remote = NULL;
@@ -270,10 +279,10 @@ void GMH323Connection::OnUserInputString(const PString & value)
 
   gnomemeeting_threads_enter ();
   if (utf8_remote && strcmp (utf8_remote, "")) 
-    gnomemeeting_text_chat_insert (utf8_remote, val, 1);
+    gnomemeeting_text_chat_insert (chat_window, utf8_remote, val, 1);
   
-  if (!GTK_WIDGET_VISIBLE (gw->chat_window))
-    gconf_set_bool (USER_INTERFACE_KEY "main_window/show_chat_window", true);
+  if (!GTK_WIDGET_VISIBLE (chat_window))
+    gm_conf_set_bool (USER_INTERFACE_KEY "main_window/show_chat_window", true);
 
   g_free (utf8_remote);
   gnomemeeting_threads_leave ();
@@ -307,12 +316,15 @@ BOOL GMH323Connection::OnReceivedFacility(const H323SignalPDU & pdu)
 void 
 GMH323Connection::HandleCallTransferFailure (const int returnError)
 {
-  GmWindow *gw = NULL;
+  GtkWidget *history_window = NULL;
+  GtkWidget *main_window = NULL;
+  
+  history_window = GnomeMeeting::Process ()->GetHistoryWindow ();
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
   
   gnomemeeting_threads_enter ();
-  gw = GnomeMeeting::Process ()->GetMainWindow ();
-  gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Call transfer failed"), _("The remote user tried to transfer your call to another user, but it failed."));
-  gnomemeeting_log_insert (_("Call transfer failed"));
+  gnomemeeting_error_dialog (GTK_WINDOW (main_window), _("Call transfer failed"), _("The remote user tried to transfer your call to another user, but it failed."));
+  gm_history_window_insert (history_window, _("Call transfer failed"));
   gnomemeeting_threads_leave ();
 }
 
