@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                          urlhandler.h  -  description
  *                          ----------------------------
  *   begin                : Sat Jun 8 2002
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : Multithreaded class to call a given URL or to
  *                          answer a call.
  *
@@ -52,11 +52,16 @@ class GMURL
   GMURL (const GMURL &);
   BOOL IsEmpty ();
   BOOL IsSupported ();
+  BOOL Find (GMURL);
   PString GetType ();
+  PString GetCanonicalURL ();
+  PString GetCalltoServer ();
+  PString GetCalltoEmail ();
   PString GetValidURL ();
   PString GetDefaultURL ();
   BOOL operator == (GMURL);
   BOOL operator != (GMURL);
+  
  private:
   PString url;
   PString type;
@@ -79,14 +84,6 @@ public:
    */
   GMURLHandler (PString, BOOL = FALSE);
 
-
-  /* DESCRIPTION  :  The constructor.
-   * BEHAVIOR     :  Initialise the parameters. GM will answer the incoming
-   *                 call (if any).
-   * PRE          :  /
-   */
-  GMURLHandler ();
-
   
   /* DESCRIPTION  :  The destructor.
    * BEHAVIOR     :  /
@@ -105,7 +102,6 @@ public:
 
 protected:
 
-  GmWindow *gw;
   GMURL url;
   BOOL answer_call;
   BOOL transfer_call;
